Contact Us
===============

Are you a company that uses ``fortls``?
Do you need technical support?
Is there a feature missing that you would like to see or have you spotted a bug?

**Reach out and let us know!**


You can reach out in a number of ways:

- Start a `GitHub Discussion <https://github.com/fortran-lang/fortls/discussions>`__.
- Ask a question on `Fortran Language Discourse <https://fortran-lang.discourse.group/>`__ and tag `@gnikit <https://fortran-lang.discourse.group/u/gnikit/>`__ in your post.
- For Feature Requests open an issue on `GitHub <https://github.com/fortran-lang/fortls/issues/new/choose>`__.
- For Bug Reports, open a bug report on `GitHub <https://github.com/fortran-lang/fortls/issues/new/choose>`__. Make sure to check the open GitHub issues!
- For any other inquiry contact ``gnikit [@] duck [.] com``
